Given a date and a day of the week, Given a date return the next month's first Tuesday
Usage
next_date(month, which = "Tues", n = 1, call = rlang::caller_env())Arguments
- month
Character/Date. The current month. Date returned is the next month.
- which
Character/Numeric. Which week day to return. Either number or abbreviated English weekday.
- n
Numeric. The nth week to return (i.e. the 1st Tuesday if
n = 1andwhich = "Tues").- call
Environment. Calling environment for appropriate messages if used within another function.