List open PRs by url, title and number, optionally matching to a title or branch name (ref)
Usage
prs_list(match = NULL, owner = "ropensci", repo = "roweb3")
Arguments
- match
Character. String to match in the title or branch name
- owner
Character. GitHub owner of the repository (defaults to 'ropensci')
- repo
Character. GitHub repository name (defaults to 'roweb3')
Value
Data frame with PR url, number, title, and branch name ('ref')
Examples
prs_list("coworking") # List all coworking related (open) PRs
#> ⠙ 9 items, page 1 | 2ms
#> # A tibble: 0 × 4
#> # ℹ 4 variables: html_url <chr>, number <int>, title <chr>, ref <chr>