Skip to contents

Use matomo_update() and friends to download and update blog post view data. tt_review() summarizes the posts by view and optionally filters to a specific month.

Usage

tt_review(which_month = NULL)

Arguments

which_month

Numeric. Which month to return? Numeric 1-12 for month. Default NULL returns all.

Value

Data frame of posts by views with urls

Examples

if (FALSE) { # dir.exists(matomo_dir())
tt_review(11)
}