Skip to contents

Add specific words to the wordlist

Usage

wordlist_update(words, path = ".wordlist/names.txt")

Arguments

words

Character vector. Words to add to word list, note that these are all split into individual words by spaces.

path

Character. Where the word list is to be saved/updated.

Value

Path of word list