Create draft message for checking in with Cohosts about the Event review
Source:R/coworking.R
cw_checkin_event.RdWhen an event has been drafted use this draft text to invite the cohost(s) to review via Slack or Email.
Arguments
- which
Character/Date. "next" to fetch details on the next coworking session, "last" to fetch details on the last scheduled (in future) coworking session, or a Date fetch details for a specific coworking session.
- names
Character. Names of cohost if overriding those in the event listing.
Logical. Whether to print the copied text to the console.