Create help-wanted socials_post_issue() command
Arguments
- help
Data frame. Formatted help-wanted issues including social media handles and arranged by platform upon which to post, output of
by_platform().- date_time
Character/Date. When to post. Defaults to next Thursday if
NULL.- dry_run
Logical. Whether to do a dry run (i.e. don't post)
Logical. Whether to simply print the text to console instead of copying to the clipboard.
Examples
if (FALSE) { # interactive()
h <- help_fetch("2025-05-23") |>
help_handles() |>
by_platform()
help_post(h, print = TRUE) # For non-interactive examples
}