R/keys.R
keys_set.Rd
This function guides uses through the finding and setting tokens so that promoutils can find them.
keys_set(type = NULL)
Character Vector. Keys/tokens to set ("slack", "matomo", "linkedin", "github").
Nothing, side effect of setting token credentials in the keyring or via gitcreds::gitcres_set() for GitHub tokens.
gitcreds::gitcres_set()