List open PRs by url, title and number, optionally matching to a title or branch name (ref)
Usage
prs_list(match = NULL, owner = "ropensci", repo = "roweb3")
Arguments
- match
Character. String to match in the title or branch name
- owner
Character. GitHub owner of the repository (defaults to 'ropensci')
- repo
Character. GitHub repository name (defaults to 'roweb3')
Value
Data frame with PR url, number, title, and branch name ('ref')
Examples
prs_list("coworking") # List all coworking related (open) PRs
#> # A tibble: 1 × 4
#> html_url number title ref
#> <chr> <int> <chr> <chr>
#> 1 https://github.com/ropensci/roweb3/pull/1301 1301 Add July 2026 Cowor… cowo…